==> fastapi-better-di-0.2.0.tar.gz: fastapi-better-di-0.2.0/README.md <==
# fastapi-better-di

## What is this ?
`fastapi-better-di` is a utility that allows you to use DI in fastapi without Depends()

## Installation

```shell
pip install fastapi_better_di
```

## Examples

1.

```python
# routes.py
from fastapi import APIRouter

from custom_types import MyType

api = APIRouter()


@api.get("/")
def handler(my_type: MyType):  # <- DI without Depends()
    return {"my_type": my_type.value}
```

```python
# app.py
from fastapi import FastAPI
from fastapi_better_di.patcher.auto import is_pathed

from custom_types import MyType

assert is_pathed(), "Something went wrong"

app = FastAPI()

# Register types for DI
app.dependency_overrides[MyType] = lambda: MyType(123)


def register_routers():
    # Importing routers after initializing main app
    from routes import api

    app.include_router(router=api)


register_routers()
```

2. [See full examples](examples)

## Usage

You have 2 use cases:

1. Use patching:
    * Auto patching: patches classes when importing:
      ```python
      from fastapi_better_di.patcher.auto import is_pathed # The classes were patched immediately after import

      # To check if everything is OK, use assert
      assert is_pathed(), "Something went wrong"
      ```

    * Manual patching: you need to call `patch()` by yourself:
      ```python
      from fastapi_better_di.patcher.manual import patch, is_pathed

      patch()
      
      # To check if everything is OK, use assert
      assert is_pathed(), "Something went wrong"
      ```

    * [Patching example](examples/patching)
2. Use DI Classes: `FastAPIDI, APIRouterDI, APIRouteDI`
    * Use `FastAPIDI` instead of `FastAPI`
    * Use `APIRouterDI` instead of `APIRouter`
    * Use `APIRouteDI` instead of `APIRoute`
    * [DI Classes example](examples/simple)

* **IMPORTANT**: You can still use `= Depends()` without a function as an argument,
  and it won't add unnecessary arguments to the swagger.
  * Related issue: [fastapi issue](https://github.com/tiangolo/fastapi/issues/4118)

* **IMPORTANT**: The main app(`FastAPI`) and `dependency_overrides` must be initialized before importing routers!

## How it works

`fastapi-better-di` simply patch the handler function and add `= Depends(func)` as the default argument

==> fastapi-better-di-0.3.3.tar.gz: fastapi-better-di-0.3.3/README.md <==
# fastapi-better-di

## What is this ?
`fastapi-better-di` is a utility that allows you to use DI in fastapi without Depends()

## Installation

```shell
pip install fastapi_better_di
```

## Examples

```python
# app.py
import uvicorn
from fastapi import FastAPI
from fastapi_better_di.patcher.auto import is_pathed
# functions were patched immediately after import

assert is_pathed(), "Something went wrong"


class MyType:
    def __init__(self, value):
        self.value = value


app = FastAPI()
app.dependency_overrides[MyType] = lambda: MyType(123)


@app.get("/")
def handler(my_type: MyType):  # <- DI without `Depends()`
    assert my_type.value == 123
    return my_type


if __name__ == "__main__":
    uvicorn.run(app)
```

[See all examples](examples)

## Usage

1. Patching:
    * Auto patching: patches classes when importing:
      ```python
      from fastapi_better_di.patcher.auto import is_pathed # The classes were patched immediately after import

      # To check if everything is OK, use assert
      assert is_pathed(), "Something went wrong"
      ```

    * Manual patching: you need to call `patch()` by yourself:
      ```python
      from fastapi_better_di.patcher.manual import patch, is_pathed

      patch()
      
      # To check if everything is OK, use assert
      assert is_pathed(), "Something went wrong"
      ```

    * [Examples](examples)


* **IMPORTANT**: You can still use `= Depends()` without a function as an argument,
  and it won't add unnecessary arguments to the swagger.
  * Related issue: [fastapi issue](https://github.com/tiangolo/fastapi/issues/4118)

* **IMPORTANT**: The main app(`FastAPI`) and `dependency_overrides` must be initialized before importing routers!

## How it works

`fastapi-better-di` simply patch the handler function and add `= Depends(func)` as the default argument
